@@ -1,5 +1,6 @@
 require_relative 'boot'
 
+require 'rails'
 # Pick the frameworks you want:
 require 'active_model/railtie'
 require 'active_job/railtie'
@@ -14,8 +15,6 @@ require 'action_cable/engine'
 require 'sprockets/railtie'
 # require "rails/test_unit/railtie"
 
-require 'resque/server'
-
 # Require the gems listed in Gemfile, including any gems
 # you've limited to :test, :development, or :production.
 Bundler.require(*Rails.groups)
@@ -23,7 +22,18 @@ Bundler.require(*Rails.groups)
 module Dradis
   class Application < Rails::Application
     # Initialize configuration defaults for originally generated Rails version.
-    config.load_defaults 6.1
+    config.load_defaults 7.2
+
+    # Change the format of the cache entry. Changing this default means that all new cache entries
+    # added to the cache will have a different format that is not supported by Rails 7.0 applications.
+    config.active_support.cache_format_version = 7.1
+
+    # Please, add to the `ignore` list any other `lib` subdirectories that do
+    # not contain `.rb` files, or that should not be reloaded or eager loaded.
+    # Common ones are `templates`, `generators`, or `middleware`, for example.
+    config.autoload_lib(ignore: %w[assets dradis html tasks templates])
+
+    config.active_record.default_column_serializer = YAML
 
     # Configuration for the application, engines, and railties goes here.
     #
@@ -36,11 +46,13 @@ module Dradis
       env.export_concurrent = false
     end
     config.action_view.form_with_generates_remote_forms = true
-    config.active_record.yaml_column_permitted_classes = [
-      'ActiveModel::Errors',
-      'Symbol',
-      'UserPreferences'
-    ]
+
+    # Override the default credentials lookup paths. See bin/rails credentials:help
+    config.credentials.content_path = Rails.root.join('config', 'shared', 'credentials.yml.enc')
+    config.credentials.key_path = Rails.root.join('config', 'shared', 'master.key')
+
+    # Don't generate system test files.
+    config.generators.system_tests = nil
   end
 end
 
